@@ -55,7 +55,11 @@ class TicketBackend(ModelBackend):
         """
         api_params = {"bk_ticket": bk_ticket}
         try:
-            response = send(resolve_login_url(ConfFixture.USER_INFO_URL, request), "GET", api_params)
+            response = send(
+                resolve_login_url(ConfFixture.USER_INFO_URL, request, "http"),
+                "GET",
+                api_params,
+            )
             ret = response.get("ret")
 
             if ret == 0:
